@@ -1,3 +1,4 @@
+
 Glover <- function(DCM,ts){
 
 Kernel <- spm_kernels(DCM)
@@ -8,7 +9,8 @@ for (i in 1:DCM$n){
 H <- fft(Kernel[,i,1])
 M <- fft(ts[,i])
 N0 <- DCM$v*DCM$Ce[(i-1)*DCM$v+1,(i-1)*DCM$v+1]
-na[,i] <- as.real(as.real(fft(Conj(H)*M)/(as.real(H*Conj(H))+N0),inverse=TRUE))/DCM$v
+na[,i] <- as.double(as.double(fft(Conj(H)*M)/(as.double(H*Conj(H))+N0),inverse=TRUE))/DCM$v
+#na[,i] <- as.real(as.real(fft(Conj(H)*M)/(as.real(H*Conj(H))+N0),inverse=TRUE))/DCM$v
 #na[,i] <- as.real(fft(Conj(H)*M/(as.real(H*Conj(H))),inverse=TRUE))/DCM$v
 }
 #na<-as.matrix(na)
