@@ -3,7 +3,7 @@ function(dfdx,f,t){
 dfdx<-as.matrix(dfdx)
 f <- as.matrix(f)
     #t<-t/sqrt(eigen2(dfdx%*%t(dfdx))$values[1])
-    t<-t/sqrt(spm_eigen(dfdx%*%t(dfdx))[NROW(dfdx)])
+    t<-t/sqrt(eigen(dfdx%*%t(dfdx))$values[1])
     if (t > 10^8){
 	    dx = -solve(dfdx)%*%f
       }
